@@ -6,6 +6,7 @@ from wfuzz.fuzzobjects import FuzzResult
 from wfuzz.fuzzobjects import FuzzRequest
 from wfuzz.plugin_api.base import BasePayload
 from wfuzz.externals.moduleman.plugin import moduleman_plugin
+from wfuzz.utils import rgetattr
 
 
 @moduleman_plugin
@@ -14,7 +15,7 @@ class autorize(BasePayload):
     author = ("Xavi Mendez (@xmendez)",)
     version = "0.1"
     description = ("Reads burp extension autorize states",)
-    summary = "Returns fuzz results' from autororize."
+    summary = "Returns fuzz results' from autorize."
     category = ["default"]
     priority = 99
 
@@ -41,7 +42,7 @@ class autorize(BasePayload):
     def __next__(self):
         next_item = next(self._it)
 
-        return next_item if not self.attr else next_item.get_field(self.attr)
+        return next_item if not self.attr else rgetattr(next_item, self.attr)
 
     def _gen_wfuzz(self, output_fn):
         try:
