@@ -3,6 +3,7 @@ from wfuzz.plugin_api.base import BasePayload
 
 import sys
 
+
 @moduleman_plugin
 class stdin(BasePayload):
     name = "stdin"
@@ -20,21 +21,15 @@ class stdin(BasePayload):
 
     def __init__(self, params):
         BasePayload.__init__(self, params)
-
-	# stdin is unseekable
-	self.__count = -1
-	#self.__count=len(sys.stdin.readlines())
-	#sys.stdin.seek(0)
+        self.__count = -1
 
     def count(self):
-	return self.__count
+        return self.__count
 
-    def __iter__ (self):
-	return self
+    def __iter__(self):
+        return self
 
-    def next (self):
-	#line=sys.stdin.next().strip().split(':')
-	line = sys.stdin.next().strip()
-
-	return line
+    def __next__(self):
+        line = next(sys.stdin).strip()
 
+        return line
