@@ -1,4 +1,8 @@
-from urlparse import urljoin
+# Python 2 and 3
+try:
+    from urllib.parse import urljoin
+except ImportError:
+    from urlparse import urljoin
 
 from wfuzz.plugin_api.urlutils import check_content_type
 
@@ -8,7 +12,8 @@ from wfuzz.externals.moduleman.plugin import moduleman_plugin
 
 # Entries format based on:
 # http://docstore.mik.ua/orelly/other/cvs/cvs-CHP-6-SECT-9.htm
-# Good example at http://webscantest.com/CVS/Entries 
+# Good example at http://webscantest.com/CVS/Entries
+
 
 @moduleman_plugin
 class cvs_extractor(BasePlugin, DiscoveryPluginMixin):
@@ -26,17 +31,17 @@ class cvs_extractor(BasePlugin, DiscoveryPluginMixin):
         BasePlugin.__init__(self)
 
     def validate(self, fuzzresult):
-	return fuzzresult.url.find("CVS/Entries") >= 0 and fuzzresult.code == 200 and check_content_type(fuzzresult, 'text')
+        return fuzzresult.url.find("CVS/Entries") >= 0 and fuzzresult.code == 200 and check_content_type(fuzzresult, 'text')
 
     def process(self, fuzzresult):
-	base_url = urljoin(fuzzresult.url, "..")
+        base_url = urljoin(fuzzresult.url, "..")
 
-	for line in fuzzresult.history.content.splitlines():
-	    record = line.split("/")
-	    if len(record) == 6 and record[1]:
-		self.queue_url(urljoin(base_url, record[1]))
+        for line in fuzzresult.history.content.splitlines():
+            record = line.split("/")
+            if len(record) == 6 and record[1]:
+                self.queue_url(urljoin(base_url, record[1]))
 
-		# Directory
-		if record[0] == 'D':
-		    self.queue_url(urljoin(base_url, record[1]))
-		    self.queue_url(urljoin(base_url, "%s/CVS/Entries" % (record[1])))
+                # Directory
+                if record[0] == 'D':
+                    self.queue_url(urljoin(base_url, record[1]))
+                    self.queue_url(urljoin(base_url, "%s/CVS/Entries" % (record[1])))
